@@ -21,11 +21,10 @@ For interface details see L<Bugzilla::DB> and L<DBI>.
 
 package Bugzilla::DB::Oracle;
 
-use 5.10.1;
-use strict;
-use warnings;
+use 5.14.0;
+use Moo;
 
-use parent qw(Bugzilla::DB);
+extends qw(Bugzilla::DB);
 
 use DBD::Oracle;
 use DBD::Oracle qw(:ora_types);
@@ -46,7 +45,7 @@ use constant BLOB_TYPE       => {ora_type => ORA_BLOB};
 use constant MIN_LONG_READ_LEN => 32 * 1024;
 use constant FULLTEXT_OR       => ' OR ';
 
-sub new {
+sub BUILDARGS {
   my ($class, $params) = @_;
   my ($user, $pass, $host, $dbname, $port)
     = @$params{qw(db_user db_pass db_host db_name db_port)};
@@ -66,24 +65,21 @@ sub new {
     LongReadLen =>
       max(Bugzilla->params->{'maxattachmentsize'} || 0, MIN_LONG_READ_LEN) * 1024,
   };
-  my $self = $class->db_new(
-    {dsn => $dsn, user => $user, pass => $pass, attrs => $attrs});
+  return {dsn => $dsn, user => $user, pass => $pass, attrs => $attrs};
+}
 
-  # Needed by TheSchwartz
-  $self->{private_bz_dsn} = $dsn;
-
-  bless($self, $class);
+sub on_dbi_connected {
+  my ($class, $dbh) = @_;
 
   # Set the session's default date format to match MySQL
-  $self->do("ALTER SESSION SET NLS_DATE_FORMAT='YYYY-MM-DD HH24:MI:SS'");
-  $self->do("ALTER SESSION SET NLS_TIMESTAMP_FORMAT='YYYY-MM-DD HH24:MI:SS'");
-  $self->do("ALTER SESSION SET NLS_LENGTH_SEMANTICS='CHAR'")
+  $dbh->do("ALTER SESSION SET NLS_DATE_FORMAT='YYYY-MM-DD HH24:MI:SS'");
+  $dbh->do("ALTER SESSION SET NLS_TIMESTAMP_FORMAT='YYYY-MM-DD HH24:MI:SS'");
+  $dbh->do("ALTER SESSION SET NLS_LENGTH_SEMANTICS='CHAR'")
     if Bugzilla->params->{'utf8'};
 
   # To allow case insensitive query.
-  $self->do("ALTER SESSION SET NLS_COMP='ANSI'");
-  $self->do("ALTER SESSION SET NLS_SORT='BINARY_AI'");
-  return $self;
+  $dbh->do("ALTER SESSION SET NLS_COMP='ANSI'");
+  $dbh->do("ALTER SESSION SET NLS_SORT='BINARY_AI'");
 }
 
 sub bz_last_key {
@@ -748,11 +744,11 @@ sub _get_create_trigger_ddl {
 
 package Bugzilla::DB::Oracle::st;
 
-use 5.10.1;
+use 5.14.0;
 use strict;
 use warnings;
 
-use parent -norequire, qw(DBI::st);
+use base -norequire, qw(DBI::st);
 
 sub fetchrow_arrayref {
   my $self = shift;
