@@ -7,13 +7,13 @@
 
 package Bugzilla::User::Setting::Timezone;
 
-use 5.10.1;
+use 5.14.0;
 use strict;
 use warnings;
 
 use DateTime::TimeZone;
 
-use parent qw(Bugzilla::User::Setting);
+use base qw(Bugzilla::User::Setting);
 
 use Bugzilla::Constants;
 
