@@ -7,11 +7,11 @@
 
 package Bugzilla::Extension::BmpConvert;
 
-use 5.10.1;
+use 5.14.0;
 use strict;
 use warnings;
 
-use parent qw(Bugzilla::Extension);
+use base qw(Bugzilla::Extension);
 
 use Image::Magick;
 
