@@ -7,15 +7,15 @@
 
 package Bugzilla::Extension::Example::WebService;
 
-use 5.10.1;
+use 5.14.0;
 use strict;
 use warnings;
-use parent qw(Bugzilla::WebService);
+use base qw(Bugzilla::WebService);
 use Bugzilla::Error;
 
 use constant PUBLIC_METHODS => qw(
-    hello
-    throw_an_error
+  hello
+  throw_an_error
 );
 
 # This can be called as Example.hello() from the WebService.
